SettingsTile<T> class

Inheritance

Constructors

SettingsTile({Widget? leading, Widget? trailing, required Widget title, Widget? description, dynamic onPressed(BuildContext)?, bool enabled = true, Key? key})
SettingsTile.checkboxTile({required bool? initialValue, required dynamic onToggle(bool?)?, Widget? leading, Widget? trailing, required Widget title, Widget? description, bool enabled = true, Key? key})
SettingsTile.navigation({Widget? leading, Widget? trailing, Widget? value, required Widget title, Widget? description, dynamic onPressed(BuildContext)?, bool enabled = true, Key? key})
SettingsTile.radioTile({required T radioValue, required T? groupValue, required dynamic onChanged(T?)?, Widget? leading, Widget? trailing, required Widget title, Widget? description, bool enabled = true, Key? key})
SettingsTile.switchTile({required bool? initialValue, required dynamic onToggle(bool?)?, Widget? leading, Widget? trailing, required Widget title, Widget? description, bool enabled = true, Key? key})

Properties

description → Widget?
The widget at the bottom of the title
final
enabled ↔ bool
Whether this tile is clickable
latefinal
groupValue ↔ T?
The bool value used by switch
latefinal
hashCode → int
The hash code for this object.
no setterinherited
initialValue ↔ bool?
The bool value used by switch
latefinal
isDesktop → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading → Widget?
The widget at the beginning of the tile
final
onChanged ↔ dynamic Function(T?)?
A function that is called by tap on a radio button
latefinal
onPressed ↔ dynamic Function(BuildContext)?
A function that is called by tap on a tile
latefinal
onToggle ↔ dynamic Function(bool?)?
A function that is called by tap on a switch or checkbox !! Caution: bool value could be null, you may have to add null check
latefinal
radioValue ↔ T
The bool value used by switch
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tileType ↔ SettingsTileType
latefinal
title → Widget
The widget at the center of the tile
final
trailing → Widget?
The Widget at the end of the tile
final
value ↔ Widget?
The text displayed at the end of the tile
latefinal

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
buildLeading(BuildContext context) → Widget
buildTileContent(BuildContext context) → Widget
buildTitle(BuildContext context) → Widget
buildTrailing(BuildContext context) → Widget
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

thumbIcon → const WidgetStateProperty<Icon>